@@ -202,6 +202,14 @@ gkd_secret_prompt_constructed (GObject *obj)
 			  G_CALLBACK (prompt_method_prompt), self);
 }
 
+void
+gkd_secret_prompt_unexport (GkdSecretPrompt *self)
+{
+	g_return_if_fail (self->pv->skeleton != NULL);
+	g_dbus_interface_skeleton_unexport (G_DBUS_INTERFACE_SKELETON (self->pv->skeleton));
+	g_clear_object (&self->pv->skeleton);
+}
+
 static void
 gkd_secret_prompt_init (GkdSecretPrompt *self)
 {
